import pygame

def create_grid(rows, cols):
    """
    This function creates and returns a list of lists, intended to
    represent a grid. All of the grid cells are filled with False.
    """
    grid = []
    for r in range(0,rows):
        row = []
        for c in range(0, cols):
            row = row + [False]
        grid = grid + [row]
    return grid

def draw_grid(win, grid, size, margin):
    """
    This function takes a grid representation and draws it. False is
    represented as magenta, True as orange.
    """
    
    for row_index in range(0,len(grid)):
        for col_index in range(0, len(grid[row_index])):
            if grid[row_index][col_index]:
                color = pygame.color.Color("orange")
            else:
                color = pygame.color.Color("darkmagenta")
            x = col_index*(size+margin)
            y = row_index*(size+margin)
            pygame.draw.rect(win,color,(x, y, size, size))

            
def run_game():
    
    ## Initialize the pygame submodules and set up the display window.

    pygame.init()

    width = 650
    height = 600
    my_win = pygame.display.set_mode((width,height))


    ## Initialize game objects.

    ## GAME LOOP starts
    keepGoing = True    
    while (keepGoing):

        ## Handle events.

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                keepGoing = False


        ## Update game objects.


        ## Draw picture and update display.

        my_win.fill(pygame.color.Color("lightblue"))
        draw_grid(my_win, grid, size, margin)
        pygame.display.update()

    ## GAME LOOP ends

    pygame.quit()


## To test:
size = 10
margin = 2
grid = create_grid(0,0)
run_game()

size = 10
margin = 2
grid = create_grid(3,4)
run_game()

grid = create_grid(50,50)
grid[10][5] = True
grid[10][6] = True
grid[10][7] = True
run_game()





