import pygame

def create_grid(rows, cols):
    """
    This function creates and returns a list of lists, intended to
    represent a grid. All of the grid cells are filled with False.
    """
    grid = []
    for r in range(0,rows):
        row = []
        for c in range(0, cols):
            row = row + [False]
        grid = grid + [row]
    return grid

def draw_grid(win, grid, size, margin):
    """
    This function takes a grid representation and draws it. False is
    represented as magenta, True as orange.
    """
    
    for row_index in range(0,len(grid)):
        for col_index in range(0, len(grid[row_index])):
            if grid[row_index][col_index]:
                color = pygame.color.Color("orange")
            else:
                color = pygame.color.Color("darkmagenta")
            x = col_index*(size+margin)
            y = row_index*(size+margin)
            pygame.draw.rect(win,color,(x, y, size, size))

            
def run_game():
    
    ## Initialize the pygame submodules and set up the display window.

    pygame.init()

    width = 650
    height = 600
    my_win = pygame.display.set_mode((width,height))


    ## Initialize game objects.
    size = 10
    margin = 2
    rows = 50
    cols = 50
    grid = create_grid(rows, cols)

    ## GAME LOOP starts
    keepGoing = True    
    while (keepGoing):

        ## Handle events.

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                keepGoing = False

            # handle mouse clicks
            elif event.type == pygame.MOUSEBUTTONDOWN:

                (mouse_x, mouse_y) = event.pos

                # within grid area
                if (mouse_x <= (margin + size) * rows
                    and mouse_x <= (margin + size) * cols):

                    col = mouse_x / (size + margin)
                    row = mouse_y / (size + margin)

                    grid[row][col] = not grid[row][col]


        ## Update game objects.


        ## Draw picture and update display.

        my_win.fill(pygame.color.Color("lightblue"))
        draw_grid(my_win, grid, size, margin)
        pygame.display.update()

    ## GAME LOOP ends

    pygame.quit()


## To test:
run_game()

# and click in various spots




