import pygame

def create_grid(rows, cols):
    """
    This function creates and returns a list of lists, intended to
    represent a grid. All of the grid cells are filled with False.
    """
    grid = []
    for r in range(0,rows):
        row = []
        for c in range(0, cols):
            row = row + [False]
        grid = grid + [row]
    return grid

def draw_grid(win, grid, size, margin):
    """
    This function takes a grid representation and draws it. False is
    represented as magenta, True as orange.
    """
    
    for row_index in range(0,len(grid)):
        for col_index in range(0, len(grid[row_index])):
            if grid[row_index][col_index]:
                color = pygame.color.Color("orange")
            else:
                color = pygame.color.Color("darkmagenta")
            x = col_index*(size+margin)
            y = row_index*(size+margin)
            pygame.draw.rect(win,color,(x, y, size, size))

            
def run_game():
    
    ## Initialize the pygame submodules and set up the display window.

    pygame.init()

    width = 650
    height = 600
    my_win = pygame.display.set_mode((width,height))


    ## Initialize game objects.
    # the grid
    size = 10
    margin = 2
    rows = 50
    cols = 50
    grid = create_grid(rows, cols)

    # reset button
    reset_radius = 20
    reset_x = width - reset_radius - 2
    reset_y = reset_radius + 2

    # the go button
    go_radius = 20
    go_x = width - go_radius - 4
    go_y = 2 + 2* reset_radius + go_radius + 4
    go = False

    
    ## GAME LOOP starts
    keepGoing = True    
    while (keepGoing):

        ## Handle events.

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                keepGoing = False

            # handle mouse clicks
            elif event.type == pygame.MOUSEBUTTONDOWN:

                (mouse_x, mouse_y) = event.pos

                # within grid area
                if (mouse_x <= (margin + size) * rows
                    and mouse_x <= (margin + size) * cols):

                    col = mouse_x / (size + margin)
                    row = mouse_y / (size + margin)

                    grid[row][col] = not grid[row][col]

                # on reset button
                elif (mouse_x > reset_x - reset_radius and mouse_x < reset_x + reset_radius
                    and mouse_y > reset_y - reset_radius and mouse_y < reset_y + reset_radius):

                    grid = create_grid(rows, cols)

                # on start/stop button
                elif (mouse_x > go_x - go_radius and mouse_x < go_x + go_radius
                    and mouse_y > go_y - go_radius and mouse_y < go_y + go_radius):

                    go = not go

                    print go



        ## Update game objects.


        ## Draw picture and update display.

        my_win.fill(pygame.color.Color("lightblue"))
        
        draw_grid(my_win, grid, size, margin)
        pygame.draw.circle(my_win, pygame.color.Color("white"), (reset_x, reset_y), reset_radius)
        pygame.draw.circle(my_win, pygame.color.Color("red"), (go_x, go_y), go_radius)
        pygame.display.update()

    ## GAME LOOP ends

    pygame.quit()


## To test:
run_game()

# and click the go button a few times




